var searchData=
[
  ['openmpt_5fcould_5fopen_5fprobability',['openmpt_could_open_probability',['../group__libopenmpt__c.html#ga281464dbc5cd791126eed6f819b0171e',1,'libopenmpt.h']]],
  ['openmpt_5fcould_5fopen_5fprobability2',['openmpt_could_open_probability2',['../group__libopenmpt__c.html#ga33393fb514f79e4ced5a0a5fdebfb5e3',1,'libopenmpt.h']]],
  ['openmpt_5fcould_5fopen_5fpropability',['openmpt_could_open_propability',['../group__libopenmpt__c.html#ga6b636df734a1caa154886ae0ceb33ad7',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5fdefault',['openmpt_error_func_default',['../group__libopenmpt__c.html#ga5d8d28ab0eef88f82c7ffbd28c39f361',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5ferrno',['openmpt_error_func_errno',['../group__libopenmpt__c.html#ga2bde048f9e17516ac7c1166746abb1fc',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5ferrno_5fuserdata',['openmpt_error_func_errno_userdata',['../group__libopenmpt__c.html#gaa52dec68957368f49dbcc9cd6603dadc',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5fignore',['openmpt_error_func_ignore',['../group__libopenmpt__c.html#ga0e251d4cd88cde1b7e79d4024b154a8e',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5flog',['openmpt_error_func_log',['../group__libopenmpt__c.html#ga8dfe5edd28c6590c98eaeaa93e81a625',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5ffunc_5fstore',['openmpt_error_func_store',['../group__libopenmpt__c.html#gaff878452d42b028d3c764794524f07cc',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5fis_5ftransient',['openmpt_error_is_transient',['../group__libopenmpt__c.html#ga1e034f3145ab44065e022203e03f1f35',1,'libopenmpt.h']]],
  ['openmpt_5ferror_5fstring',['openmpt_error_string',['../group__libopenmpt__c.html#gaaf339f2d1db4afe7042e7976cd34dd22',1,'libopenmpt.h']]],
  ['openmpt_5ffree_5fstring',['openmpt_free_string',['../group__libopenmpt__c.html#ga0fb70a57725fc29499c557974f16a873',1,'libopenmpt.h']]],
  ['openmpt_5fget_5fcore_5fversion',['openmpt_get_core_version',['../group__libopenmpt__c.html#gae10ab2bd98577a7023a211807889bd07',1,'libopenmpt.h']]],
  ['openmpt_5fget_5flibrary_5fversion',['openmpt_get_library_version',['../group__libopenmpt__c.html#gac53f78258568ddfb07be07ec33b1b9b6',1,'libopenmpt.h']]],
  ['openmpt_5fget_5fstring',['openmpt_get_string',['../group__libopenmpt__c.html#ga8ae1e912761e09f398f16d9f347248ca',1,'libopenmpt.h']]],
  ['openmpt_5fget_5fsupported_5fextensions',['openmpt_get_supported_extensions',['../group__libopenmpt__c.html#ga6fff8e3cf426e01e6434d084233c43c5',1,'libopenmpt.h']]],
  ['openmpt_5fis_5fextension_5fsupported',['openmpt_is_extension_supported',['../group__libopenmpt__c.html#ga7a5f19f790dad4ab9deb62d4f4e6bbc4',1,'libopenmpt.h']]],
  ['openmpt_5flog_5ffunc_5fdefault',['openmpt_log_func_default',['../group__libopenmpt__c.html#ga67648b980fac7134b5ac124d934d5750',1,'libopenmpt.h']]],
  ['openmpt_5flog_5ffunc_5fsilent',['openmpt_log_func_silent',['../group__libopenmpt__c.html#ga3d83925bb2083e25515a79a48321a4ce',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fcreate',['openmpt_module_create',['../group__libopenmpt__c.html#ga4552be0a5fe6dbc25fe195d1586cb79f',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fcreate2',['openmpt_module_create2',['../group__libopenmpt__c.html#ga1c92733a25f1c01c2cda2528ccc4e415',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fcreate_5ffrom_5fmemory',['openmpt_module_create_from_memory',['../group__libopenmpt__c.html#ga53377a365f001a99ae4626918e55b25e',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fcreate_5ffrom_5fmemory2',['openmpt_module_create_from_memory2',['../group__libopenmpt__c.html#ga8237a4d9dfb0f33c7cd0a2926f30a25f',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fget',['openmpt_module_ctl_get',['../group__libopenmpt__c.html#ga20d871022840893e6f4cb13ad78a0ff7',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fget_5fboolean',['openmpt_module_ctl_get_boolean',['../group__libopenmpt__c.html#ga79c1fc512437220d9f65556723326c78',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fget_5ffloatingpoint',['openmpt_module_ctl_get_floatingpoint',['../group__libopenmpt__c.html#gac6e1f6ec3d9cc82fa3df5e63dc5b5350',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fget_5finteger',['openmpt_module_ctl_get_integer',['../group__libopenmpt__c.html#gab4cd78a172569a5d02c4e41c3caac18c',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fget_5ftext',['openmpt_module_ctl_get_text',['../group__libopenmpt__c.html#ga13b040e57fd61854766b3d3fdca14b3a',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fset',['openmpt_module_ctl_set',['../group__libopenmpt__c.html#ga384de8fb7266821e7a3677460861593e',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fset_5fboolean',['openmpt_module_ctl_set_boolean',['../group__libopenmpt__c.html#gab178566ca8e2280f4389370200b00ad5',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fset_5ffloatingpoint',['openmpt_module_ctl_set_floatingpoint',['../group__libopenmpt__c.html#ga7af8284475e3411b25d3f8c9686b02e6',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fset_5finteger',['openmpt_module_ctl_set_integer',['../group__libopenmpt__c.html#ga6a3990be4d7140e255fbc96e1eaed3db',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fctl_5fset_5ftext',['openmpt_module_ctl_set_text',['../group__libopenmpt__c.html#ga8a4b646f940bd9e9527dbda4edbeca17',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fdestroy',['openmpt_module_destroy',['../group__libopenmpt__c.html#ga40d27bb0ef054c3cd5e7ae3e85ed64e1',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5ferror_5fclear',['openmpt_module_error_clear',['../group__libopenmpt__c.html#gaceaa2675b539674c1611d1e8a392aa87',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5ferror_5fget_5flast',['openmpt_module_error_get_last',['../group__libopenmpt__c.html#ga7ffc363899565eebe05d38a670050c83',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5ferror_5fget_5flast_5fmessage',['openmpt_module_error_get_last_message',['../group__libopenmpt__c.html#ga026a8746a423af3747f9f61998594e15',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5ferror_5fset_5flast',['openmpt_module_error_set_last',['../group__libopenmpt__c.html#ga80114288acfa1d1ae2bfdff571545c47',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fext_5fcreate',['openmpt_module_ext_create',['../group__libopenmpt__ext__c.html#gadc0eaf6067b9a1bdfd04db9aaa22286a',1,'libopenmpt_ext.h']]],
  ['openmpt_5fmodule_5fext_5fcreate_5ffrom_5fmemory',['openmpt_module_ext_create_from_memory',['../group__libopenmpt__ext__c.html#gac6bacf019368fe78ebcc2511c15ae039',1,'libopenmpt_ext.h']]],
  ['openmpt_5fmodule_5fext_5fdestroy',['openmpt_module_ext_destroy',['../group__libopenmpt__ext__c.html#ga737466596e917bd196c7b30496aad1b8',1,'libopenmpt_ext.h']]],
  ['openmpt_5fmodule_5fext_5fget_5finterface',['openmpt_module_ext_get_interface',['../group__libopenmpt__ext__c.html#ga0275a35da407cd092232a20d3535c9e4',1,'libopenmpt_ext.h']]],
  ['openmpt_5fmodule_5fext_5fget_5fmodule',['openmpt_module_ext_get_module',['../group__libopenmpt__ext__c.html#gace3ad42bcb313134e6e13c4eb16ba333',1,'libopenmpt_ext.h']]],
  ['openmpt_5fmodule_5fformat_5fpattern_5frow_5fchannel',['openmpt_module_format_pattern_row_channel',['../group__libopenmpt__c.html#gad031f518dd6bcbcd86daaacd1a3a97f2',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fformat_5fpattern_5frow_5fchannel_5fcommand',['openmpt_module_format_pattern_row_channel_command',['../group__libopenmpt__c.html#ga13c81dffe7c50db41826a4da28713f9b',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fchannel_5fname',['openmpt_module_get_channel_name',['../group__libopenmpt__c.html#ga35b34623ad43234f71b2fc6f1bdc67ac',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fctls',['openmpt_module_get_ctls',['../group__libopenmpt__c.html#ga9a7a95ee4073243b1193120c9107ce99',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5fleft',['openmpt_module_get_current_channel_vu_left',['../group__libopenmpt__c.html#ga2fdc099414e6be2172ab43a41628937a',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5fmono',['openmpt_module_get_current_channel_vu_mono',['../group__libopenmpt__c.html#ga498bd8b7f699671ef573522cf908bc65',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5frear_5fleft',['openmpt_module_get_current_channel_vu_rear_left',['../group__libopenmpt__c.html#ga3c5d64718d0d574bf94bd9f13aa3b8a1',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5frear_5fright',['openmpt_module_get_current_channel_vu_rear_right',['../group__libopenmpt__c.html#ga459facd9def73d056190a76882da29b6',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5fright',['openmpt_module_get_current_channel_vu_right',['../group__libopenmpt__c.html#gab90660d5d9fa932cfff118023c4b56c8',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5festimated_5fbpm',['openmpt_module_get_current_estimated_bpm',['../group__libopenmpt__c.html#gae3ed09be74bd9e5dc78d424608a17e72',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5forder',['openmpt_module_get_current_order',['../group__libopenmpt__c.html#ga88bd245db9a3e857443920bf68f093a6',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fpattern',['openmpt_module_get_current_pattern',['../group__libopenmpt__c.html#ga9f2013da0ddda5888d8ac9821193c269',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fplaying_5fchannels',['openmpt_module_get_current_playing_channels',['../group__libopenmpt__c.html#ga145570605cff14c147d096e93bd16dbc',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5frow',['openmpt_module_get_current_row',['../group__libopenmpt__c.html#ga18079a93aa8ed0452718ed88ad8942be',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5fspeed',['openmpt_module_get_current_speed',['../group__libopenmpt__c.html#ga3e6e38f688443cb9d002626a1516dcfd',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fcurrent_5ftempo',['openmpt_module_get_current_tempo',['../group__libopenmpt__c.html#gab00cde7c1a2b17ebbecd677bd2e7c281',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fduration_5fseconds',['openmpt_module_get_duration_seconds',['../group__libopenmpt__c.html#ga3d243ff23a128ac52e8148343c52618f',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5finstrument_5fname',['openmpt_module_get_instrument_name',['../group__libopenmpt__c.html#ga6fad3256eb4123f930d519fc74e01d73',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fmetadata',['openmpt_module_get_metadata',['../group__libopenmpt__c.html#gac171f8fb2c7a0b998855956069159068',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fmetadata_5fkeys',['openmpt_module_get_metadata_keys',['../group__libopenmpt__c.html#ga79ab73081485c4bd8cdf80e638003893',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5fchannels',['openmpt_module_get_num_channels',['../group__libopenmpt__c.html#ga1a511e81ccada3f70aebd0854ae9c2d9',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5finstruments',['openmpt_module_get_num_instruments',['../group__libopenmpt__c.html#ga0d557f95d21d8cdaadbc35f0d5e2be60',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5forders',['openmpt_module_get_num_orders',['../group__libopenmpt__c.html#ga8ad3c291b61619556556bb991f3b62f8',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5fpatterns',['openmpt_module_get_num_patterns',['../group__libopenmpt__c.html#gae8fa17a20133ebc64a26305aa181cc4c',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5fsamples',['openmpt_module_get_num_samples',['../group__libopenmpt__c.html#gaadd84c34e34a322dd645df68923c7fe5',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fnum_5fsubsongs',['openmpt_module_get_num_subsongs',['../group__libopenmpt__c.html#ga41be89e94d250be0941b4eb56e56c1c8',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5forder_5fname',['openmpt_module_get_order_name',['../group__libopenmpt__c.html#ga071d326f349e97d6728d77fc1402099f',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5forder_5fpattern',['openmpt_module_get_order_pattern',['../group__libopenmpt__c.html#ga46159826ab2854615c9872dd6eb61256',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fpattern_5fname',['openmpt_module_get_pattern_name',['../group__libopenmpt__c.html#gaa4a2d323f4052c89f1d75013cdf35eb4',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fpattern_5fnum_5frows',['openmpt_module_get_pattern_num_rows',['../group__libopenmpt__c.html#ga8e1a6c3ad88b325825a4ec046500f322',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fpattern_5frow_5fchannel_5fcommand',['openmpt_module_get_pattern_row_channel_command',['../group__libopenmpt__c.html#ga0daf4f417af31c67f5e514ec67a60cde',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fposition_5fseconds',['openmpt_module_get_position_seconds',['../group__libopenmpt__c.html#ga9507836c6d63771742d570919d417533',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5frender_5fparam',['openmpt_module_get_render_param',['../group__libopenmpt__c.html#ga7620687f3681690616dffe8d356f9df9',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5frepeat_5fcount',['openmpt_module_get_repeat_count',['../group__libopenmpt__c.html#ga25c205297bb4c001b341e000fd6d0820',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fsample_5fname',['openmpt_module_get_sample_name',['../group__libopenmpt__c.html#gaf33b4ab4ad556ea3d654c04e6454d510',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fselected_5fsubsong',['openmpt_module_get_selected_subsong',['../group__libopenmpt__c.html#gad0ca32c54b27090e08005ccbb9477d3c',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fget_5fsubsong_5fname',['openmpt_module_get_subsong_name',['../group__libopenmpt__c.html#gafd8716078c53af4bb761016e9c7477a1',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fhighlight_5fpattern_5frow_5fchannel',['openmpt_module_highlight_pattern_row_channel',['../group__libopenmpt__c.html#gadbfc90800a26de5330b47ee137ba7f7d',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fhighlight_5fpattern_5frow_5fchannel_5fcommand',['openmpt_module_highlight_pattern_row_channel_command',['../group__libopenmpt__c.html#ga9d6981fa546cf4e5553f93d81b0f332f',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5ffloat_5fmono',['openmpt_module_read_float_mono',['../group__libopenmpt__c.html#ga59437852eaaf2630813eb07edeb83aca',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5ffloat_5fquad',['openmpt_module_read_float_quad',['../group__libopenmpt__c.html#ga28cfbb80190e5b4ddabc5975a47384ce',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5ffloat_5fstereo',['openmpt_module_read_float_stereo',['../group__libopenmpt__c.html#gac310145e86bd88d5f38f3168073014fc',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5finterleaved_5ffloat_5fquad',['openmpt_module_read_interleaved_float_quad',['../group__libopenmpt__c.html#ga7ff2eac8523bb05b39b541ab21f02f2e',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5finterleaved_5ffloat_5fstereo',['openmpt_module_read_interleaved_float_stereo',['../group__libopenmpt__c.html#ga036901606728ce00d9f104adca6a5c09',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5finterleaved_5fquad',['openmpt_module_read_interleaved_quad',['../group__libopenmpt__c.html#ga4be8b5fad0607953cc760ca739ac3cb9',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5finterleaved_5fstereo',['openmpt_module_read_interleaved_stereo',['../group__libopenmpt__c.html#gac8331183f8a0a453f0fbdc4791fd79cb',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5fmono',['openmpt_module_read_mono',['../group__libopenmpt__c.html#gabb9d640ef27e3c289a88831a4ad28c7e',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5fquad',['openmpt_module_read_quad',['../group__libopenmpt__c.html#gae2d0b54c815605e7f86d32e49bb8befc',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fread_5fstereo',['openmpt_module_read_stereo',['../group__libopenmpt__c.html#ga8e2766307479bcef46464d8bb2b957a6',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fselect_5fsubsong',['openmpt_module_select_subsong',['../group__libopenmpt__c.html#ga523fe9d172709472049941899c9835f2',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5ferror_5ffunc',['openmpt_module_set_error_func',['../group__libopenmpt__c.html#gaed6b9e12835aa9d17713eb1d8e8bed3b',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5flog_5ffunc',['openmpt_module_set_log_func',['../group__libopenmpt__c.html#ga2b9002a91ab97038c67d95abbc973de4',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5fposition_5forder_5frow',['openmpt_module_set_position_order_row',['../group__libopenmpt__c.html#gac4e234c38901822134feb37721ada825',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5fposition_5fseconds',['openmpt_module_set_position_seconds',['../group__libopenmpt__c.html#ga43b63d715b1a8b287d6b4ef1708fbc93',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5frender_5fparam',['openmpt_module_set_render_param',['../group__libopenmpt__c.html#gaecd0bb67bb3b720340bb12f5df86db2a',1,'libopenmpt.h']]],
  ['openmpt_5fmodule_5fset_5frepeat_5fcount',['openmpt_module_set_repeat_count',['../group__libopenmpt__c.html#gaad2167f7a943f630a72af9b57a586491',1,'libopenmpt.h']]],
  ['openmpt_5fprobe_5ffile_5fheader',['openmpt_probe_file_header',['../group__libopenmpt__c.html#gaac34f4d87dd3c3e59b12daac81935d6c',1,'libopenmpt.h']]],
  ['openmpt_5fprobe_5ffile_5fheader_5ffrom_5fstream',['openmpt_probe_file_header_from_stream',['../group__libopenmpt__c.html#ga52ee99cdabedc1953682e347e5f77afb',1,'libopenmpt.h']]],
  ['openmpt_5fprobe_5ffile_5fheader_5fget_5frecommended_5fsize',['openmpt_probe_file_header_get_recommended_size',['../group__libopenmpt__c.html#gaf5860bba2af2c4b02b8daa4539216f1a',1,'libopenmpt.h']]],
  ['openmpt_5fprobe_5ffile_5fheader_5fwithout_5ffilesize',['openmpt_probe_file_header_without_filesize',['../group__libopenmpt__c.html#ga92cdc66eb529a8a4a67987b659ed3c5e',1,'libopenmpt.h']]],
  ['openmpt_5fstream_5fbuffer_5finit',['openmpt_stream_buffer_init',['../group__libopenmpt__c.html#ga527b70571e44f6c4f0066d4a10670da4',1,'libopenmpt_stream_callbacks_buffer.h']]],
  ['openmpt_5fstream_5fbuffer_5fread_5ffunc',['openmpt_stream_buffer_read_func',['../group__libopenmpt__c.html#gae95f26d25828cd5c46e7a3b7d556b9f4',1,'libopenmpt_stream_callbacks_buffer.h']]],
  ['openmpt_5fstream_5fbuffer_5fseek_5ffunc',['openmpt_stream_buffer_seek_func',['../group__libopenmpt__c.html#gacc76d42781b233ba4717dcf0dc415eec',1,'libopenmpt_stream_callbacks_buffer.h']]],
  ['openmpt_5fstream_5fbuffer_5ftell_5ffunc',['openmpt_stream_buffer_tell_func',['../group__libopenmpt__c.html#ga9101861fab39cd6993b206dc0270e6c5',1,'libopenmpt_stream_callbacks_buffer.h']]],
  ['openmpt_5fstream_5ffd_5fread_5ffunc',['openmpt_stream_fd_read_func',['../group__libopenmpt__c.html#ga534305a50c22c68f4eb4735ac6e271db',1,'libopenmpt_stream_callbacks_fd.h']]],
  ['openmpt_5fstream_5ffile_5fread_5ffunc',['openmpt_stream_file_read_func',['../group__libopenmpt__c.html#gab35f4ca3b71e20cabdc2febb5d48db87',1,'libopenmpt_stream_callbacks_file.h']]],
  ['openmpt_5fstream_5ffile_5fseek_5ffunc',['openmpt_stream_file_seek_func',['../group__libopenmpt__c.html#ga53dd106d28a4b68eea86fba6bfdd1b9a',1,'libopenmpt_stream_callbacks_file.h']]],
  ['openmpt_5fstream_5ffile_5ftell_5ffunc',['openmpt_stream_file_tell_func',['../group__libopenmpt__c.html#gaecc775ac3096e1a1060941e0ef8ee0ec',1,'libopenmpt_stream_callbacks_file.h']]],
  ['openmpt_5fstream_5fget_5fbuffer_5fcallbacks',['openmpt_stream_get_buffer_callbacks',['../group__libopenmpt__c.html#gaacc6e056e2161e64184079e0f23d34b0',1,'libopenmpt_stream_callbacks_buffer.h']]],
  ['openmpt_5fstream_5fget_5ffd_5fcallbacks',['openmpt_stream_get_fd_callbacks',['../group__libopenmpt__c.html#ga9b222cad5195de39b84503c089eca611',1,'libopenmpt_stream_callbacks_fd.h']]],
  ['openmpt_5fstream_5fget_5ffile_5fcallbacks',['openmpt_stream_get_file_callbacks',['../group__libopenmpt__c.html#gac89b0366fe1f3686bcff1be86b69c79a',1,'libopenmpt_stream_callbacks_file.h']]]
];
